@@ -21,7 +21,6 @@ from . import cert, socks
 
 class ProxyRequestHandler(BaseHTTPRequestHandler):
     protocol_version = 'HTTP/1.1'
-    admin_path = None
     # Path to the directory used to store the generated certificates.
     # Subclasses can override certdir
     certdir = cert.CERTDIR
@@ -54,10 +53,6 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
             self.close_connection = True
 
     def proxy_request(self):
-        if self.admin_path and self.path.startswith(self.admin_path):
-            self.handle_admin()
-            return
-
         req = self
         content_length = int(req.headers.get('Content-Length', 0))
         req_body = self.rfile.read(content_length) if content_length else None
@@ -71,7 +66,7 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
 
         req_body_modified = self.handle_request(req, req_body)
         if req_body_modified is False:
-            self.send_error(403)
+            # Response already committed
             return
         elif req_body_modified is not None:
             req_body = req_body_modified
@@ -85,9 +80,8 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
             req.headers['Host'] = netloc
         setattr(req, 'headers', self._filter_headers(req.headers))
 
-        origin = (scheme, netloc)
         try:
-            conn = self._create_connection(origin)
+            conn = self._create_connection((scheme, netloc))
             conn.request(self.command, path, req_body, dict(req.headers))
             res = conn.getresponse()
 
@@ -115,22 +109,13 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
 
         setattr(res, 'headers', self._filter_headers(res.headers))
 
-        self.send_response(res.status, res.reason)
-
-        for header, val in res.headers.items():
-            self.send_header(header, val)
-        self.end_headers()
-
-        if res_body:
-            self.wfile.write(res_body)
-
-        self.wfile.flush()
-
-        if self.websocket:
-            self._handle_websocket(conn.sock)
-            self.close_connection = True
-        elif not self._keepalive():
-            self.close_connection = True
+        self.commit_response(
+            res.status,
+            res.reason,
+            res.headers,
+            res_body,
+            conn
+        )
 
     def _create_connection(self, origin):
         scheme, netloc = origin
@@ -167,6 +152,7 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
             'keep-alive',
             'proxy-authenticate',
             'proxy-authorization',
+            'proxy-connection',
             'te',
             'trailers',
             'transfer-encoding',
@@ -255,6 +241,10 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
     def handle_request(self, req, req_body):
         """Hook method that subclasses should override to process a request.
 
+        If the request body has been modified, it should be returned from the method.
+        Returning False will indicate that the response has been committed and no
+        further processing will take place.
+
         Args:
             req: A ProxyRequestHandler instance.
             req_body: The request body as bytes.
@@ -264,6 +254,8 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
     def handle_response(self, req, req_body, res, res_body):
         """Hook method that subclasses should override to process a response.
 
+        If the response body has been modified, it should be returned from the method.
+
         Args:
             req: The original request - a ProxyRequestHandler instance.
             req_body: The request body as bytes.
@@ -273,19 +265,23 @@ class ProxyRequestHandler(BaseHTTPRequestHandler):
         """
         pass
 
-    def handle_admin(self):
-        """Subclasses should override this to process administration requests.
+    def commit_response(self, status, reason, headers, body, conn=None):
+        self.send_response(status, reason)
 
-        Administration requests are requests targeted at the proxy server itself
-        rather than a remote server.
+        for header, val in headers.items():
+            self.send_header(header, val)
+        self.end_headers()
 
-        Note that subclasses must set the admin_path class-level attribute to
-        a URL prefix that identifies administration requests. For example:
-            admin_path = 'http://myserver'
-        This method will then fire for any request with a URL path that starts
-        with http://myserver...
-        """
-        pass
+        if body:
+            self.wfile.write(body)
+
+        self.wfile.flush()
+
+        if self.websocket and conn is not None:
+            self._handle_websocket(conn.sock)
+            self.close_connection = True
+        elif not self._keepalive():
+            self.close_connection = True
 
 
 class ProxyAwareHTTPConnection(HTTPConnection):
