@@ -9,20 +9,47 @@ logging.basicConfig(level=logging.DEBUG)
 class BrowserIntegrationTest(TestCase):
 
     def test_simple_example(self):
-        # Create a new instance of the Firefox driver
-        driver = webdriver.Firefox()
+        def getDriver():
+            PATHCHROMEDRIVER = "/PATH/chromedriver"
 
-        # Go to the Google home page
-        driver.get('https://www.google.com')
+            # Configure Web-driver
+            chrome_options = webdriver.ChromeOptions()
+            chrome_options.headless = True
+            chrome_options.page_load_strategy = 'none'
+            chrome_options.add_argument('--incognito')
+            chrome_options.add_argument('--no-sandbox')
+            chrome_options.add_argument('--disable-dev-shm-usage')
+            chrome_options.add_argument('--start-maximized')
+            chrome_options.add_argument('--disable-infobars')
+            chrome_options.add_argument('--disable-gpu')
+            chrome_options.add_argument('--disable-extensions')
 
-        # Access requests via the `requests` attribute
-        for request in driver.requests:
-            if request.response:
-                print(
-                    request.url,
-                    request.response.status_code,
-                    request.response.headers['Content-Type']
-                )
+            optionssw = {
+                # 'backend': 'mitmproxy',
+                'verify_ssl': False,
+                'connection_timeout': None
+            }
+
+            return webdriver.Chrome(options=chrome_options, seleniumwire_options=optionssw)
+
+        # Create a new instance of the Chrome driver
+        driver = getDriver()
+
+        try:
+            # urlstring = "https://sp24-test.garr.it/Shibboleth.sso/Login?entityID=https://idp.aco.net/idp/shibboleth"
+            urlstring = "https://sp24-test.garr.it/Shibboleth.sso/Login?entityID=https://idp.oh-tech.org/idp/shibboleth"
+            driver.get(urlstring)
+
+            for request in driver.requests:
+                print(request.url)
+                if request.response and str(request.response.headers.get('Content-Type')).startswith('text/html'):
+                    if (request.response.status_code == 302): continue
+                    print("request.response.status_code")
+                    htmlRet = driver.page_source
+                    print("htmlRet")
+
+        finally:
+            driver.quit()
 
     def test_firefox_can_access_requests(self):
         url = 'https://www.python.org/'
